@@ -2,6 +2,8 @@ import os
 import subprocess
 import json
 
+from .download_bitwarden import DownloadBitwarden
+
 
 class Bitwarden(object):
     """
@@ -44,7 +46,7 @@ class Bitwarden(object):
                 timeout=180,
             )
         except FileNotFoundError:
-            self.path_to_exe_file = os.path.join(os.getcwd(), self.path_to_exe_file)
+            self.path_to_exe_file = DownloadBitwarden.download_bitwarden()
             return subprocess.run(
                 [
                     self.path_to_exe_file,
